@@ -4,6 +4,15 @@ use base qw(Business::ISBN);
 
 use Business::ISBN qw(:all);
 
+use subs qw(
+	_checksum
+	INVALID_GROUP_CODE
+	INVALID_PUBLISHER_CODE
+	BAD_CHECKSUM
+	GOOD_ISBN
+	BAD_ISBN
+	);
+
 use vars qw(
 	$VERSION
 	$debug
@@ -15,7 +24,7 @@ use Carp qw(carp croak cluck);
 
 my $debug = 0;
 
-$VERSION   = '2.011_01';
+$VERSION   = '2.07';
 
 sub _max_length { 10 }
 
@@ -80,8 +89,6 @@ sub _checksum {
 
 __END__
 
-=encoding utf8
-
 =head1 NAME
 
 Business::ISBN10 - work with 10 digit International Standard Book Numbers
@@ -98,7 +105,7 @@ See L<Business::ISBN>
 
 This source is in Github:
 
-    https://github.com/briandfoy/business-isbn
+    https://github.com/briandfoy/business--isbn
 
 =head1 AUTHOR
 
@@ -106,7 +113,7 @@ brian d foy C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2001-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright (c) 2001-2014, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
